@@ -1,10 +1,12 @@
 #!/usr/bin/perl
 
-use strict;
+use v5.26;
 use warnings;
 
 use Device::Chip::NoritakeGU_D;
 use Device::Chip::Adapter;
+
+use Future::AsyncAwait;
 use Getopt::Long qw( :config no_ignore_case );
 use Time::HiRes qw( sleep );
 
@@ -16,18 +18,18 @@ GetOptions(
 
 my $chip = Device::Chip::NoritakeGU_D->new( interface => $INTERFACE );
 
-$chip->mount_from_paramstr(
+await $chip->mount_from_paramstr(
    Device::Chip::Adapter->new_from_description( $ADAPTER ),
    $MOUNTPARAMS,
-)->get;
+);
 
-$chip->power(1)->get;
+await $chip->power(1);
 
-$chip->initialise->get;
+await $chip->initialise;
 
 while(1) {
    sleep 0.1;
 
-   my $switches = $chip->read_touchswitches->get;
+   my $switches = await $chip->read_touchswitches;
    $switches->{$_} and print "KEY $_\n" for sort keys %$switches;
 }
